@@ -73,20 +73,28 @@ class Experiment(ABC):
 
     def reduceDims(self, mode='avg'):
         """
-        Réduit les dimensions T, Z, X d'une matrice (T, Z, X, N) par 2 en utilisant une convolution.
+        Réduit les dimensions T, Z, X d'une matrice (T, Z, X, N) ou (T, Z, X) par 2 en utilisant une convolution.
         Args:
-            matrix (torch.Tensor ou np.ndarray): Matrice d'entrée de forme (T, Z, X, N).
             mode (str): 'avg' (moyenne) ou 'max' (max-pooling).
-        Returns:
-            torch.Tensor: Matrice réduite de forme (T//2, Z//2, X//2, N).
         """
-        for i, field in enumerate(self.AcousticFields):
+        for i in trange(len(self.AcousticFields),
+                        desc="Downsampling Acoustic Fields (T, Z, X → T//2, Z//2, X//2)"):
             # Conversion en tenseur PyTorch si nécessaire
-            if isinstance(field.field, np.ndarray):
-                field.field = torch.from_numpy(field.field)
+            if isinstance(self.AcousticFields[i].field, np.ndarray):
+                self.AcousticFields[i].field = torch.from_numpy(self.AcousticFields[i].field)
+
+            # Vérification de la forme du tenseur
+            if self.AcousticFields[i].field.dim() == 3:
+                # Cas (T, Z, X) : ajout d'une dimension fictive N=1
+                x = self.AcousticFields[i].field.unsqueeze(-1)  # (T, Z, X, 1)
+            elif self.AcousticFields[i].field.dim() == 4:
+                # Cas (T, Z, X, N) : permutation normale
+                x = self.AcousticFields[i].field
+            else:
+                raise ValueError(f"Forme non supportée : {self.AcousticFields[i].field.shape}")
 
             # Permutation des axes pour adapter à conv3d: (N, 1, T, Z, X)
-            x = field.field.permute(3, 0, 1, 2).unsqueeze(1)  # Ajoute un canal fictif
+            x = x.permute(3, 0, 1, 2).unsqueeze(1)  # (N, 1, T, Z, X)
 
             # Réduction par convolution 3D
             if mode == 'avg':
@@ -98,12 +106,13 @@ class Experiment(ABC):
 
             # Retour à l'ordre original (T//2, Z//2, X//2, N)
             self.AcousticFields[i].field = x_down.squeeze(1).permute(1, 2, 3, 0)
-        
+
+        # Mise à jour des paramètres
         self.params.acoustic['f_saving'] /= 2
         self.params.general['dx'] *= 2
         self.params.general['dz'] *= 2
         self.params.general['dy'] *= 2
-
+        
     def saveAcousticFields(self, save_directory):
         progress_bar = trange(len(self.AcousticFields), desc="Saving Acoustic Fields")
         for i in progress_bar:
